clear all
format shortG 
warning('off','MATLAB:nearlySingularMatrix')

% set file path
% cd ('path to replication files')
cd('C:\Users\Mast\Dropbox\tax_incentives\Papers\aeja_submission\final\replication_files')

% add matlab functions to path
addpath('matlab_functions')

% set directory to data
cd ('data')

% load estimation file
load('full_formatted_data')

%% set parameters
param_rack=[ -400, 547, .325, 56700;
    -600,611,.292,43500;
    -800, 790,.237,13900
];
param_dim=size(param_rack);
param_num=param_dim(1);

%% get the actual stats in the data for comparison 

% get total subsidies
actual_town_subsidy=struct_id;
for i=1:1096;
    actual_town_subsidy(i)=sum(property_exemptions_2013(struct_id_auct==i & active_2013==1));
end;

% get total revenue
actual_town_revenue=struct_id;
for i=1:1096;
    actual_town_revenue(i)=property_tax_2013(i)*sum(prop(struct_id_auct==i & active_2013==1));
end;

actual_town_revenue=actual_town_revenue-actual_town_subsidy;

% get total jobs
actual_town_employment=struct_id;
for i=1:1096;
    actual_town_employment(i)=sum(emp(struct_id_auct==i & active_2013==1));
end;

% get the simple stats
total_subsidy=sum(actual_town_subsidy);
total_revenue=sum(actual_town_revenue);
median_revenue=median(actual_town_revenue);

%% run a series of counterfactuals for each value of the parameters
match_set_storage=zeros(param_num,1);
match_mode_storage=match_set_storage;

for param_i = 1:3;
    param=param_rack(param_i,:);
    
    % first we do status quo simulation
    sims=2;
    sq_raw=status_quo(param,struct_id,struct_id_auct,distances,poverty_percent,property_tax_2013,property_tax_2008,exemption_year,ida_vector,prop,emp, liability_2008, liability_2013, property_tax,bid_options, ...
                                        bid_plans,num,sims, county_number,pref_loc_matrix,error_mat,active_2013);
    sq_total_subsidy=sq_raw{1}(1);
    sq_total_revenue=sq_raw{1}(2);
    sq_raw_locations=sq_raw{2};

    % then subsidy ban simulation
    sims=2;
    sb_raw=subsidy_ban(param,struct_id,struct_id_auct,distances,poverty_percent,property_tax_2013,property_tax_2008,exemption_year,ida_vector,prop,emp, liability_2008, liability_2013, property_tax,bid_options, ...
                                        bid_plans,num,sims, county_number,pref_loc_matrix,error_mat,active_2013);
    sb_total_revenue=sb_raw{1}(1);
    sb_total_subsidy=0;
    sb_raw_locations=sb_raw{2};
    
    % then county only
    sims=2;
    ci_raw=county_idas(param,struct_id,struct_id_auct,distances,poverty_percent,property_tax_2013,property_tax_2008,exemption_year,ida_vector,prop,emp, liability_2008, liability_2013, property_tax,bid_options, ...
                                        bid_plans,num,sims, county_number,pref_loc_matrix,error_mat,active_2013);
    ci_total_subsidy=ci_raw{1}(1);
    ci_total_revenue=ci_raw{1}(2);                                
    ci_raw_locations=ci_raw{2};

    % compare the aggregate stats
    sums_subsidies_cell{param_i}=[total_subsidy,total_revenue; ...
        sq_total_subsidy,sq_total_revenue; ...
        sb_total_subsidy, sb_total_revenue; ...
        ci_total_subsidy,ci_total_revenue]

 

    for i = 1:length(match_set_sqsb);

        bop=tabulate(sb_raw_locations(i,:));
        boop=bop(:,1);
        bip=bop(:,2);
        
        if (max(bip)<13);
            
            g5_sb=99999;
            
        end;
        
        if (max(bip)>12);
            
            g5_sb=boop(bip>12);
            
        end;
        
        bop=tabulate(sq_raw_locations(i,:));
        boop=bop(:,1);
        bip=bop(:,2);      
        
        if (max(bip)<13);
            
            g5_sq=99999;
            
        end;
        
        if (max(bip)>12);
            
            g5_sq=boop(bip>12);
            
        end;
        
        bop=tabulate(ci_raw_locations(i,:));
        boop=bop(:,1);
        bip=bop(:,2);
        
        if (max(bip)<13);
            
            g5_ci=99999;
            
        end;
        
        if (max(bip)>12);
            
            g5_ci=boop(bip>12);
            
        end;

        if (length(g5_sq)==length(g5_sb));
            
            match_set_sqsb(i)=mean((g5_sq==g5_sb));
            
        end;

        if (length(g5_sq)~=length(g5_sb));
            
            match_set_sqsb(i)=0;
            
        end;   

        if (length(g5_sq)==length(g5_ci));
            
            match_set_sqci(i)=mean((g5_sq==g5_ci));
            
        end;

        if (length(g5_sq)~=length(g5_ci));
            
            match_set_sqci(i)=0;
            
        end;      

        if (length(g5_ci)==length(g5_sb));
            
            match_set_sbci(i)=mean((g5_ci==g5_sb)); 
            
        end;

        if (length(g5_ci)~=length(g5_sb));
            
            match_set_sbci(i)=0;
            
        end;  

    end;
    
    match_set_sqsb(match_set_sqsb<1)=0;
    match_set_sqci(match_set_sqci<1)=0;
    match_set_sbci(match_set_sbci<1)=0;

    [match_set_sqsb',match_set_sqci',match_set_sbci'];

    mean(match_set_sqsb)
    mean(match_set_sqci)
    mean(match_set_sbci)

    match_set_all=match_set_sqsb+match_set_sqci+match_set_sbci;
    bop=tabulate(match_set_all);
    shop=size(bop);
    match_set_storage(param_i)=bop(shop(1),shop(2))
    
end;







