function exemption_distribution=exemption_distribution(param,struct_id,struct_id_auct,distances,poverty_percent,property_tax_2013,property_tax_2008,exemption_year,ida_vector,prop,emp, liability_2008, liability_2013, property_tax,bid_options, ...
                                    bid_plans,z,x,z20,x20,z30,x30,z35,x35,z40,x40,true_b20_2013,true_b25_2013,true_b30_2013, ...
                                    true_b35_2013,true_b40_2013,true_percent_pos_2013,true_p25_subs_2013,true_sum_2013, ...
                                    true_b20_2008,true_b25_2008,true_b30_2008,true_b35_2008,true_b40_2008,true_percent_pos_2008,...
                                    true_p25_subs_2008,true_sum_2008,num,sims, county_number,pref_loc_matrix,active_2008,active_2013, ...
                                    true_emp_corr_2013, true_emp_corr_2008,state_sales_exemptions_2013,property_exemptions_2008,property_exemptions_2013)
tic
rng('default') 

% estimated parameters
beta_tax=param(1);
beta_distance=beta_tax/param(2);
kappa_prop=param(3);
kappa_emp=param(4);
beta_pov=0;

% matched moments
moments_true=[true_b25_2013,true_b30_2013,true_b35_2013,true_b40_2013,true_percent_pos_2013,true_p25_subs_2013,true_sum_2013,true_emp_corr_2013 ...
        true_b25_2008,true_b30_2008,true_b35_2008,true_b40_2008,true_percent_pos_2008,true_p25_subs_2008,true_sum_2008, true_emp_corr_2008];

% simulation parameters
inner_num=50;

% initialize storage
final_loc=zeros(num,inner_num);
subsidy_2013=final_loc;
subsidy_2008=final_loc;
sum_sub_2013=zeros(inner_num,1);
sum_sub_2008=sum_sub_2013;
aux_emp_corr_2013=sum_sub_2013;
aux_emp_corr_2008=sum_sub_2013;
aux_prop_corr_2013=sum_sub_2013;
aux_prop_corr_2008=sum_sub_2013;
percent_pos_aux_int_2013=sum_sub_2013;
percent_pos_aux_int_2008=percent_pos_aux_int_2013;
p25_subs_aux_int_2013=sum_sub_2013;
p25_subs_aux_int_2008=p25_subs_aux_int_2013;
d_metric=.816*ones(sims,1);
sum_aux_2013=d_metric;
sum_aux_2008=d_metric;
moments_aux=zeros(sims,16);
pl=zeros(num,1);

%% run simulation

for sim=1:sims;
    
    parfor obs=1:num;
        
        % pull the preferred location for the firms
        pref_loc=pref_loc_matrix(obs,sim);
        
        % nab the possible locations
        possible_loc = struct_id(distances(pref_loc,:)<40);
        
        % get the municipal given those possible locations
        bidders=[intersect(possible_loc,ida_vector)];
        bidder_ind=ismember(possible_loc,ida_vector);
        num_idas=length(bidders);
        
        % get the county idas
        counties=county_number(possible_loc);
        unique_counties=unique(counties);
        num_counties=length(unique_counties);
        county_towns=cell(num_counties,1);
        county_ind=county_towns;
        
        for i=1:num_counties;
            
            county_towns{i}=possible_loc(counties==unique_counties(i));
            county_towns{i}=setdiff(county_towns{i},ida_vector);
            county_ind{i}=ismember(possible_loc,county_towns{i});
            
        end;
        
        num_bidders=num_idas+num_counties;

        %% run through an equilibrium in IDA offers

        % bidder valuations
        valuations=repmat(kappa_prop*prop(obs)+kappa_emp*emp(obs),num_bidders,1);
        
        % tv attractiveness
        delta=beta_distance*distances(pref_loc,possible_loc)' + beta_tax*property_tax(possible_loc);

        % look for an equilibrium, first by initializing bids
        ibr=ones(num_idas,1);
        new_ibr=ibr;
        cbr=ones(num_counties,1);
        new_cbr=cbr;
        dd=1;
        it=1;

        % split by cases, first where we have some municipal IDAs
        if (num_idas>0);
            
            % this loop iterates to a fixed point
            while (dd>0);
                
                % load choice variables from previous iteration
                ibr=new_ibr;
                cbr=new_cbr;
                delta_perm=zeros(1,length(delta));
                delta_county=county_towns;
                
                % compute deltas given the running bids
                % we'll call this one delta_perm and leave it constant
                % through the iteration.  we'll change delta as bidders
                % change their bid.
                for i=1:num_counties;
                    
                    delta_county{i}=beta_distance*distances(pref_loc,county_towns{i})' + ...
                        beta_tax/15*((15-bid_options(cbr(i)))*ones(length(county_towns{i}),1)).*property_tax(county_towns{i});
                    delta_perm(county_ind{i}==1)=delta_county{i};
                    
                end;
                
                delta_ida=beta_distance*distances(pref_loc,bidders)' + beta_tax/15*((15*ones(num_idas,1)-bid_options(ibr)')).*property_tax(bidders);
                delta_perm(bidder_ind==1)=delta_ida;
                
                % let county idas choose their best-response over a grid
                for county_i=1:num_counties;
                    
                    county_profits=zeros(10,1);
                    
                    for county_br=1:10;
                        
                        % they set one bid for locating anywhere in county
                        delta=delta_perm;
                        delta(county_ind{county_i}==1)=beta_distance*distances(pref_loc,county_towns{county_i})' ...
                            + beta_tax/15*((15-bid_options(county_br))*ones(length(county_towns{county_i}),1)).*property_tax(county_towns{county_i});
                        
                        % they take an expected value over all their towns
                        for non_bidder_index=1:length(county_towns{county_i});
                            
                            county_profits(county_br)=county_profits(county_br) + exp(delta(possible_loc==county_towns{county_i}(non_bidder_index)))/(sum(exp(delta)))...
                                *(valuations(county_i)*(1+beta_pov*poverty_percent(possible_loc==county_towns{county_i}(non_bidder_index)))...
                                -bid_options(county_br)*prop(obs)*property_tax(possible_loc==county_towns{county_i}(non_bidder_index)));
                            
                        end;
                        
                    end;
                    
                    [~,new_cbr(county_i)]=max(county_profits); 
                    
                end;

                % now municipal idas
                for a=1:num_idas;
                    
                    delta=delta_perm;
                    profits=zeros(10,1);
                    
                    for ida_br=1:10;
                        
                        delta(possible_loc==bidders(a))=beta_distance*distances(pref_loc,bidders(a))' + beta_tax/15*(15-bid_options(ida_br))*property_tax(bidders(a));
                        profits(ida_br)=exp(delta(possible_loc==bidders(a)))/(sum(exp(delta)))...
                            *(valuations(length(unique_counties)+a)*(1+beta_pov*poverty_percent(bidders(a)))...
                            -bid_options(ida_br)*prop(obs)*property_tax(bidders(a)));
                        
                    end;
                    
                    [~,new_ibr(a)]=max(profits);
                    
                end;
                
                dd=sum((new_cbr-cbr).^2) + sum((new_ibr-ibr).^2);
                
            end;
            
            % translate those to probabilities and simulate some locations
            p=exp(delta_perm)/sum(exp(delta_perm));
            final_loc(obs,:) = datasample(possible_loc,inner_num,'Weights',p);
            
            % put together bids
            bids=0*delta;
            bids(bidder_ind==1)=ibr; 
            
            for i=1:num_counties;
                
                bids(county_ind{i}==1)=cbr(i)*possible_loc(county_ind{i}==1).^0;
            
            end;
            
            % finally make the rack of winning bids         
            bip=final_loc(obs,:);
            bop=bip;

            for inner_sim=1:inner_num;

                bop(inner_sim)=bids(possible_loc==bip(inner_sim));

            end;

            subsidy(obs,:)=bop;
                       
        end;

        % in the event that there are just county idas present
        if (num_idas==0 && num_counties>1);
           
            %the while loop looks for an equilibrium
            while (dd>0);

                ibr=new_ibr;
                cbr=new_cbr;
                delta_perm=zeros(1,length(delta));
                delta_county=county_towns;

                % compute attractiveness for county IDA towns given
                % bids
                for i=1:num_counties;

                    delta_county{i}=beta_distance*distances(pref_loc,county_towns{i})' + ...
                        beta_tax/15*((15-bid_options(cbr(i)))*ones(length(county_towns{i}),1)).*property_tax(county_towns{i});
                    delta_perm(county_ind{i}==1)=delta_county{i};

                end;

                delta_ida=beta_distance*distances(pref_loc,bidders)' + beta_tax/15*((15*ones(num_idas,1)-bid_options(ibr)')).*property_tax(bidders);
                delta_perm(bidder_ind==1)=delta_ida;

                % let counties choose on a grid, as above
                for county_i=1:num_counties;

                    county_profits=zeros(10,1);

                    for county_br=1:10;

                        delta=delta_perm;
                        delta(county_ind{county_i}==1)=beta_distance*distances(pref_loc,county_towns{county_i})' ...
                            + beta_tax/15*((15-bid_options(county_br))*ones(length(county_towns{county_i}),1)).*property_tax(county_towns{county_i});

                        for non_bidder_index=1:length(county_towns{county_i});

                            county_profits(county_br)=county_profits(county_br) + exp(delta(possible_loc==county_towns{county_i}(non_bidder_index)))/(sum(exp(delta)))...
                                *(valuations(county_i)*(1+beta_pov*poverty_percent(possible_loc==county_towns{county_i}(non_bidder_index)))...
                                -bid_options(county_br)*prop(obs)*property_tax(possible_loc==county_towns{county_i}(non_bidder_index)));

                        end;

                    end;

                    [~,new_cbr(county_i)]=max(county_profits); 

                 end;

                 dd=sum((new_cbr-cbr).^2) + sum((new_ibr-ibr).^2);

            end;

            % compute probabilities and simulate final locations
            p=exp(delta_perm)/sum(exp(delta_perm));
            final_loc(obs,:) = datasample(possible_loc,inner_num,'Weights',p);
            
            % map into bids/winning bids
            bids=0*delta;
            bids(bidder_ind==1)=ibr;     

            for i=1:num_counties;

                bids(county_ind{i}==1)=cbr(i)*possible_loc(county_ind{i}==1).^0;

            end;

            bip=final_loc(obs,:);
            bop=bip;

            for inner_sim=1:inner_num;

                bop(inner_sim)=bids(possible_loc==bip(inner_sim));

            end;

            subsidy(obs,:)=bop;

        end;

        % if everything is in one county, it's pretty simple. no subsidy.
        if (num_idas==0 && num_counties==1);

            delta_perm=beta_distance*distances(pref_loc,possible_loc)' + beta_tax*property_tax(possible_loc);
            p=exp(delta_perm)/sum(exp(delta_perm));
            final_loc(obs,:) = datasample(possible_loc,inner_num,'Weights',p);
            subsidy(obs,:)=ones(1,inner_num);

        end;
        
    end;


    % given those simulations, we want to collapse subsidies to the town
    % level and get our statistics

    % first we translate the bulk subsidy to 2008/2013
    subsidy_2013=subsidy;
    subsidy_2008=subsidy;
    %sales_2013=subsidy;
    
    for inner_sim=1:inner_num;
        
        for i=1:num;
            
            subsidy_2013(i,inner_sim)=bid_plans(subsidy(i,inner_sim),max(1,2013-exemption_year(i)))*liability_2013(i)*...
                (property_tax_2013(final_loc(i,inner_sim))/property_tax_2013(struct_id_auct(i)));
            subsidy_2008(i,inner_sim)=bid_plans(subsidy(i,inner_sim),max(1,2008-exemption_year(i)))*liability_2008(i)*...
                (property_tax_2008(final_loc(i,inner_sim))/property_tax_2008(struct_id_auct(i)));

            
        end;
    
    end; 
    
end;

toc
param
% average the distance metrics across simulation for final
exemption_distribution=[final_loc(:,1),subsidy_2013(:,1),subsidy_2008(:,1),pl];

