function summer_sb=summer_sb(param,struct_id,struct_id_auct,distances,poverty_percent,property_tax_2013,property_tax_2008,exemption_year,ida_vector,prop,emp, liability_2008, liability_2013, property_tax,bid_options, ...
                                    bid_plans,num,sims, county_number,pref_loc_matrix,error_mat,active_2013)
tic
rng('default') 

% estimated parameters
beta_tax=param(1);
beta_distance=beta_tax/param(2);
kappa_prop=param(3);
kappa_emp=param(4);
beta_pov=param(5);


% simulation parameters
inner_num=50;

% initialize storage
final_loc=zeros(num,inner_num);
subsidy_2013=final_loc;
subsidy_2008=final_loc;
town_prop_total_m=zeros(1096,inner_num,sims);
town_subsidy_total_m=town_prop_total_m;
town_jobs_total_m=town_prop_total_m;

%% run simulation

for sim=1:sims;
    
    for obs=1:num;
        
        
        valuations=kappa_prop*prop(obs)+kappa_emp*emp(obs);
        
        
        % pull the preferred location for the firms
        pref_loc=pref_loc_matrix(obs,sim);
        
        % nab the possible locations
        possible_loc = struct_id(distances(pref_loc,:)<40);
    
        % tv attractiveness
        delta=beta_distance*distances(pref_loc,possible_loc)' + beta_tax*property_tax(possible_loc);

        % compute probabilities and simulate final locations
        p=exp(delta)/sum(exp(delta));
        final_loc(obs,:) = datasample(possible_loc,inner_num,'Weights',p);
        
        end_dist(obs,sim)=mean(distances(pref_loc,final_loc(obs,:)));
        firm_util(obs,sim)=mean(beta_distance*distances(pref_loc,final_loc(obs,:))' + beta_tax*property_tax(final_loc(obs,:)));
        town_val(obs,sim)=mean(1+beta_pov*poverty_percent(final_loc(obs,:)));        

    end;


    % given those simulations, we want to collapse subsidies to the town
    % level and get our statistics



    % now we collapse by struct_id. slowly;
    town_prop_total=zeros(1096,inner_num);
    town_jobs_total=zeros(1096,inner_num);
    
    for inner_sim=1:inner_num;
        
        for i=1:1096;
            
  
            final_loc_temp=final_loc(:,inner_sim);
            town_prop_total(i,inner_sim)=sum(prop(final_loc_temp==i & active_2013==1)*property_tax_2013(i));
            town_jobs_total(i,inner_sim)=sum(emp(final_loc_temp==i & active_2013==1));
            
        end;
  
    end;
      
    
    town_jobs_total_m(:,:,sim)=town_jobs_total;    
    town_prop_total_m(:,:,sim)=town_prop_total;
        
end;  

% totals
avg_total_revenue=sum(sum(sum(town_prop_total_m)))/(50*sims);
net_town_revenue=town_prop_total_m-town_subsidy_total_m;


% cdf and betas
sim_pov_cdf_rack=zeros(100,sims,inner_num);
sim_jobs_cdf_rack=sim_pov_cdf_rack;

for i=1:sims;
    for j=1:inner_num;
        a_rack=net_town_revenue(:,j,i);
        b_rack=town_jobs_total_m(:,j,i);        
        for k=1:100;
            sim_pov_cdf_rack(k,i,j)=sum(a_rack(poverty_percent<prctile(poverty_percent,k)));
            sim_jobs_cdf_rack(k,i,j)=sum(b_rack(poverty_percent<prctile(poverty_percent,k)));            
        end;
    end;
end;

sim_pov_cdf_int=mean(sim_pov_cdf_rack,2);
sim_pov_cdf=mean(sim_pov_cdf_int,3)';
    
sim_jobs_cdf_int=mean(sim_jobs_cdf_rack,2);
sim_jobs_cdf=mean(sim_jobs_cdf_int,3)';

% utilities

mean_dist=mean(mean(end_dist(active_2013==1)));
mean_firm_util=mean(mean(firm_util(active_2013==1)));
mean_town_val=mean(mean(town_val(active_2013==1)));
    
    
toc        
    
summer_sb={avg_total_revenue,final_loc,sim_pov_cdf,sim_jobs_cdf,mean_dist,mean_firm_util,mean_town_val};

