clear all
format shortG 
warning('off','MATLAB:nearlySingularMatrix')

% add matlab functions to path
addpath('matlab_functions')

% load estimation file
load('data/formatted_data')

%% 1. estimate auxiliary models for comparison
    
    sample=1:num;
    sample_exemptions_2013=property_exemptions_2013(sample);
    sample_exemptions_2008=property_exemptions_2008(sample);
    sample_ids=struct_id_auct(sample);
    sim_town_total_2008=struct_id;
    sim_town_total_2013=struct_id;
   
    for i=1:1096;
                
        sim_town_total_2013(i)=sum(sample_exemptions_2013(sample_ids==i));
        sim_town_total_2008(i)=sum(sample_exemptions_2008(sample_ids==i));     
        
    end;

     lprop_2013=log(sim_town_total_2013+1);
     lprop_2008=log(sim_town_total_2008+1);

   % compute regression coefficients
   z=[counties_within_25,pop, pop2, pop_within_25, pop2_within_25, cities_within_25, ...
        number_within_25, number2_within_25, border_within_25, estabs, estabs2, manu_percent, ...
        service_percent, business_percent, white_percent, poverty_percent, college_percent, tv_constant,county_inds];      
    x=[idas_within_25,pop, pop2, pop_within_25, pop2_within_25, cities_within_25, ...
        number_within_25, number2_within_25, border_within_25, estabs, estabs2, manu_percent, ...
        service_percent, business_percent, white_percent, poverty_percent, college_percent, tv_constant, county_inds];     
    z20=z;
    z20(:,1)=counties_within_20; 
    x20=x;
    x20(:,1)=idas_within_20;    
    z30=z;
    z30(:,1)=counties_within_30;
    x30=x;
    x30(:,1)=idas_within_30;
    z35=z;
    z35(:,1)=counties_within_35;
    x35=x;
    x35(:,1)=idas_within_35;
    z40=z;
    z40(:,1)=counties_within_40;
    x40=x;
    x40(:,1)=idas_within_40;
    
    beta_20_true_2013=(z20'*x20)^-1*z20'*lprop_2013;    
    beta_25_true_2013=(z'*x)^-1*z'*lprop_2013;        
    beta_30_true_2013=(z30'*x30)^-1*z30'*lprop_2013;
    beta_35_true_2013=(z35'*x35)^-1*z35'*lprop_2013;
    beta_40_true_2013=(z40'*x40)^-1*z40'*lprop_2013;
    beta_20_true_2008=(z20'*x20)^-1*z20'*lprop_2008;        
    beta_25_true_2008=(z'*x)^-1*z'*lprop_2008;    
    beta_30_true_2008=(z30'*x30)^-1*z30'*lprop_2008;
    beta_35_true_2008=(z35'*x35)^-1*z35'*lprop_2008;
    beta_40_true_2008=(z40'*x40)^-1*z40'*lprop_2008;
 
    true_b20_2013=beta_20_true_2013(1)   
    true_b20_2008=beta_20_true_2008(1)        
    true_b25_2013=beta_25_true_2013(1)
    true_b25_2008=beta_25_true_2008(1)       
    true_b30_2013=beta_30_true_2013(1)
    true_b30_2008=beta_30_true_2008(1) 
    true_b35_2013=beta_35_true_2013(1)
    true_b35_2008=beta_35_true_2008(1) 
    true_b40_2013=beta_40_true_2013(1)
    true_b40_2008=beta_40_true_2008(1) 
       
    % get percent of towns giving subsidy;
    pos_ind_2013=0*sim_town_total_2013;
    pos_ind_2008=pos_ind_2013;
    pos_ind_2013(sim_town_total_2013>0)=1;
    pos_ind_2008(sim_town_total_2008>0)=1;
    true_percent_pos_2013=mean(pos_ind_2013);
    true_percent_pos_2008=mean(pos_ind_2008);
    
    % 25th percentile of subsidy
    true_p25_subs_2013=prctile(sample_exemptions_2013(sample_exemptions_2013>0),25);
    true_p25_subs_2008=prctile(sample_exemptions_2008(sample_exemptions_2008>0),25);
    
    % get sum of subsidy;
    true_sum_2013=sum(sample_exemptions_2013);
    true_sum_2008=sum(sample_exemptions_2008);
    
    
    % get valuation correlations
    true_emp_corr_2013=corr(log(emp(active_2013==1 & property_exemptions_2013<1e6)+1),log(property_exemptions_2013(active_2013==1 & property_exemptions_2013<1e6)));
    true_emp_corr_2008=corr(log(emp(active_2008==1 & property_exemptions_2008<1e6)+1),log(property_exemptions_2008(active_2008==1 & property_exemptions_2008<1e6)));
  
    % put together
    moments_true=[true_b25_2013,true_b30_2013,true_b35_2013,true_b40_2013,true_percent_pos_2013,true_emp_corr_2013 ...
        true_b25_2008,true_b30_2008,true_b35_2008,true_b40_2008,true_percent_pos_2008, true_emp_corr_2008];
    
%% 2. fix preferred locations to use across estimations 

% set the seed and initialize the matrix
rng('default') 
pref_loc_matrix=zeros(num,20);

for sim=1:50;
    
    for obs=1:num;
        
        % get the guys close enough to compete
        end_point=struct_id_auct(obs);
        possible_pref_loc=struct_id(distances(end_point,:)<40);
        sector=sector_auct(obs);
        year=exemption_year(obs);

        % get the starting point probability
        if (year<2012);
            
            mkt_share_vector=mkt_shares(:,(year-1993)*5+sector);
            
        end;
        
        if (year>2011);
            
            fake_year=2011;
            mkt_share_vector=mkt_shares(:,(fake_year-1993)*5+sector);
            
        end;
        
        input_shares=mkt_share_vector(possible_pref_loc);
        denominator=sum(input_shares);
        final_share=input_shares/denominator;
        
        if (denominator==0);
            
            final_share=input_shares.^0*(1/sum(input_shares.^0));
            
        end;
        
        % simulate a preferred location
        pref_loc_matrix(obs,sim) = datasample(possible_pref_loc,1,'Weights',final_share);
        
        
    end;
    
end;

%% 3. simulate moments in model

sims=10;
param=[611,.292,43500];

simulated_moments=simulate_moments(param,struct_id,struct_id_auct,distances,poverty_percent,property_tax_2013,property_tax_2008,exemption_year,ida_vector,prop,emp, liability_2008, liability_2013, property_tax,bid_options, ...
                                    bid_plans,z,x,z20,x20,z30,x30,z35,x35,z40,x40,true_b20_2013,true_b25_2013,true_b30_2013, ...
                                    true_b35_2013,true_b40_2013,true_percent_pos_2013,true_p25_subs_2013,true_sum_2013, ...
                                    true_b20_2008,true_b25_2008,true_b30_2008,true_b35_2008,true_b40_2008,true_percent_pos_2008,...
                                    true_p25_subs_2008,true_sum_2008,num,sims, county_number,pref_loc_matrix,active_2008,active_2013, ...
                                    true_emp_corr_2013, true_emp_corr_2008,state_sales_exemptions_2013,property_exemptions_2008,property_exemptions_2013)

                                
% make histogram
hold on
bar([moments_true', simulated_moments'] );
title('Actual vs. Simulated Moments') 
ylabel('Moment Value') 
xlabel('Moment') 
legend('Actual', 'Simulated')
legend('Location','NorthEast') 
hold off

%% 4. simulate distribution of exemptions in model

sims=10;
param=[-600,611,.292,43500];


simulated_totals=exemption_distribution(param,struct_id,struct_id_auct,distances,poverty_percent,property_tax_2013,property_tax_2008,exemption_year,ida_vector,prop,emp, liability_2008, liability_2013, property_tax,bid_options, ...
                                    bid_plans,z,x,z20,x20,z30,x30,z35,x35,z40,x40,true_b20_2013,true_b25_2013,true_b30_2013, ...
                                    true_b35_2013,true_b40_2013,true_percent_pos_2013,true_p25_subs_2013,true_sum_2013, ...
                                    true_b20_2008,true_b25_2008,true_b30_2008,true_b35_2008,true_b40_2008,true_percent_pos_2008,...
                                    true_p25_subs_2008,true_sum_2008,num,sims, county_number,pref_loc_matrix,active_2008,active_2013, ...
                                    true_emp_corr_2013, true_emp_corr_2008,state_sales_exemptions_2013,property_exemptions_2008,property_exemptions_2013);
   
                          
sim_loc=simulated_totals(:,1);
sim_sub_2013=simulated_totals(:,2);
sim_sub_2008=simulated_totals(:,3);

% make histogram
hold on
histogram(log(sim_sub_2013(sim_sub_2013>0 & property_exemptions_2013>0)+1));
histogram(log(property_exemptions_2013(sim_sub_2013>0 & property_exemptions_2013>0)+1));
title('Log of subsidy fit') 
ylabel('Density') 
xlabel('Log of subsidy') 
legend('Simulated','Actual')
legend('Location','NorthWest') 
hold off
