clear all
format shortG 
warning('off','MATLAB:nearlySingularMatrix')

% add matlab functions to path
addpath('matlab_functions')

% load estimation file
load('data/formatted_pov_data')

%% set parameters
param_rack=[-600,734,.282,8340,1.11];
param_dim=size(param_rack);
param_num=param_dim(1);

% choose number of simulations
sims=10;

%% get the actual stats in the data for comparison

% get total subsidies
actual_town_subsidy=struct_id;
for i=1:1096;
    actual_town_subsidy(i)=sum(property_exemptions_2013(struct_id_auct==i & active_2013==1));
end;

% get total revenue
actual_town_revenue=struct_id;
for i=1:1096;
    actual_town_revenue(i)=property_tax_2013(i)*sum(prop(struct_id_auct==i & active_2013==1));
end;

actual_town_revenue=actual_town_revenue-actual_town_subsidy;

% get total jobs
actual_town_employment=struct_id;
for i=1:1096;
    actual_town_employment(i)=sum(emp(struct_id_auct==i & active_2013==1));
end;

% get the simple stats
total_subsidy=sum(actual_town_subsidy);
total_revenue=sum(actual_town_revenue);
median_revenue=median(actual_town_revenue);

%% run a loop for poverty parameter

% storage vectors
match_mode_storage=zeros(param_num,1);

for param_i = 1:param_num;
    
    param=param_rack(param_i,:);
    
    % first we do status quo simulation
    sq_raw=pov_status_quo(param,struct_id,struct_id_auct,distances,poverty_percent,property_tax_2013,property_tax_2008,exemption_year,ida_vector,prop,emp, liability_2008, liability_2013, property_tax,bid_options, ...
                                        bid_plans,num,sims, county_number,pref_loc_matrix,error_mat,active_2013);
    sq_total_subsidy=sq_raw{1}(1);
    sq_total_revenue=sq_raw{1}(2);
    sq_raw_locations=sq_raw{2};
    sq_prop_cdf=sq_raw{3};
    sq_jobs_cdf=sq_raw{4};
    sq_dist=sq_raw{5};
    sq_firm_util=sq_raw{6};
    sq_town_val=sq_raw{7};
    sq_life_subs=sq_raw{8};
    sq_disc_subs=sq_raw{9};
   
    % then subsidy ban simulation
    sb_raw=pov_subsidy_ban(param,struct_id,struct_id_auct,distances,poverty_percent,property_tax_2013,property_tax_2008,exemption_year,ida_vector,prop,emp, liability_2008, liability_2013, property_tax,bid_options, ...
                                        bid_plans,num,sims, county_number,pref_loc_matrix,error_mat,active_2013);
    sb_total_revenue=sb_raw{1}(1);
    sb_total_subsidy=0;
    sb_raw_locations=sb_raw{2};
    sb_prop_cdf=sb_raw{3};
    sb_jobs_cdf=sb_raw{4};
    sb_dist=sb_raw{5};
    sb_firm_util=sb_raw{6};
    sb_town_val=sb_raw{7};   
    
    % then county only
    ci_raw=pov_county_idas(param,struct_id,struct_id_auct,distances,poverty_percent,property_tax_2013,property_tax_2008,exemption_year,ida_vector,prop,emp, liability_2008, liability_2013, property_tax,bid_options, ...
                                        bid_plans,num,sims, county_number,pref_loc_matrix,error_mat,active_2013);
    ci_total_subsidy=ci_raw{1}(1);
    ci_total_revenue=ci_raw{1}(2);                                
    ci_raw_locations=ci_raw{2};
    ci_prop_cdf=ci_raw{3};
    ci_jobs_cdf=ci_raw{4};
    ci_dist=ci_raw{5};
    ci_firm_util=ci_raw{6};
    ci_town_val=ci_raw{7};    
    ci_life_subs=ci_raw{8};

    % compare the aggregate stats
    sums_subsidies_cell{param_i}=[total_subsidy,total_revenue; ...
        sq_total_subsidy,sq_total_revenue; ...
        sb_total_subsidy, sb_total_revenue; ...
        ci_total_subsidy,ci_total_revenue]

     % comparing locations
    mf_sq=mode(sq_raw_locations');
    mf_sb=mode(sb_raw_locations');
    mf_ci=mode(ci_raw_locations');

    match_most_sqsb=mf_sq*0;
    match_most_sqsb(mf_sb==mf_sq)=1;
    mean(mean(match_most_sqsb))

    match_most_sbci=mf_sq*0;
    match_most_sbci(mf_sb==mf_ci)=1;
    mean(mean(match_most_sbci))

    match_most_sqci=mf_sq*0;
    match_most_sqci(mf_sq==mf_ci)=1;
    mean(mean(match_most_sqci))

    % the modal town matches across all three counterfactuals...
    match_most_all=match_most_sqsb+match_most_sqci+match_most_sbci;
    bop=tabulate(match_most_all);
    shop=size(bop);
    match_mode_storage(param_i)=bop(shop(1),shop(2))
    
end;

%% display results

display("percent with same location, base parameters, manufacturing/finance sample")

match_mode_storage

display("actual total exemptions, manufacturing/finance sample")

total_subsidy

display("status quo simulation total exemptions, manufacturing/finance sample")

sq_total_subsidy

display("subsidy ban simulation total exemptions, manufacturing/finance sample")

sb_total_subsidy

display("county ida simulation total exemptions, manufacturing/finance sample")

ci_total_subsidy



%% look at utility for average firm (panel B of table)
avg_val=.282*mean(prop)+8340*mean(emp);
display("average winner's valuation of a firm")
[sq_town_val, ci_town_val, sb_town_val]*avg_val

display("average total tax break to a firm")
[sq_life_subs, ci_life_subs, 0]/num

display("average town surplus")
[sq_town_val, ci_town_val, sb_town_val]*avg_val-[sq_life_subs, ci_life_subs,0]/num
    


