clear all
format shortG 
warning('off','MATLAB:nearlySingularMatrix')

% add matlab functions to path
addpath('matlab_functions')

% load estimation file
load('data/full_formatted_data')

%% set parameters
param_rack=[ -400, 547, .325, 56700;
    -600,611,.292,43500;
    -800, 790,.237,13900
];
param_dim=size(param_rack);
param_num=param_dim(1);

%% get the actual stats in the data for comparison 

% get total subsidies
actual_town_subsidy=struct_id;
for i=1:1096;
    actual_town_subsidy(i)=sum(property_exemptions_2013(struct_id_auct==i & active_2013==1));
end;

% get total revenue
actual_town_revenue=struct_id;
for i=1:1096;
    actual_town_revenue(i)=property_tax_2013(i)*sum(prop(struct_id_auct==i & active_2013==1));
end;

actual_town_revenue=actual_town_revenue-actual_town_subsidy;

% get total jobs
actual_town_employment=struct_id;
for i=1:1096;
    actual_town_employment(i)=sum(emp(struct_id_auct==i & active_2013==1));
end;

% get the simple stats
total_subsidy=sum(actual_town_subsidy);
total_revenue=sum(actual_town_revenue);
median_revenue=median(actual_town_revenue);

%% run a series of counterfactuals for each value of the parameters

% choose number of simulations
sims=2;

% storage vectors
match_set_storage=zeros(param_num,1);
match_mode_storage=match_set_storage;

% loop over parameter values and do status quo, subsidy ban, and county IDA
% simulations for each

for param_i = 1:3;
    
    param=param_rack(param_i,:);
    
    % first we do status quo simulation
    sq_raw=status_quo(param,struct_id,struct_id_auct,distances,poverty_percent,property_tax_2013,property_tax_2008,exemption_year,ida_vector,prop,emp, liability_2008, liability_2013, property_tax,bid_options, ...
                                        bid_plans,num,sims, county_number,pref_loc_matrix,error_mat,active_2013);
    sq_total_subsidy=sq_raw{1}(1);
    sq_total_revenue=sq_raw{1}(2);
    sq_raw_locations=sq_raw{2};

    % then subsidy ban simulation
    sb_raw=subsidy_ban(param,struct_id,struct_id_auct,distances,poverty_percent,property_tax_2013,property_tax_2008,exemption_year,ida_vector,prop,emp, liability_2008, liability_2013, property_tax,bid_options, ...
                                        bid_plans,num,sims, county_number,pref_loc_matrix,error_mat,active_2013);
    sb_total_revenue=sb_raw{1}(1);
    sb_total_subsidy=0;
    sb_raw_locations=sb_raw{2};
    
    % then county only
    sims=2;
    ci_raw=county_idas(param,struct_id,struct_id_auct,distances,poverty_percent,property_tax_2013,property_tax_2008,exemption_year,ida_vector,prop,emp, liability_2008, liability_2013, property_tax,bid_options, ...
                                        bid_plans,num,sims, county_number,pref_loc_matrix,error_mat,active_2013);
    ci_total_subsidy=ci_raw{1}(1);
    ci_total_revenue=ci_raw{1}(2);                                
    ci_raw_locations=ci_raw{2};

    % compare the aggregate stats
    sums_subsidies_cell{param_i}=[total_subsidy,total_revenue; ...
        sq_total_subsidy,sq_total_revenue; ...
        sb_total_subsidy, sb_total_revenue; ...
        ci_total_subsidy,ci_total_revenue]

       % comparing locations
    mf_sq=mode(sq_raw_locations');
    
    
    mf_sb=mode(sb_raw_locations');
    mf_ci=mode(ci_raw_locations');

    match_most_sqsb=mf_sq*0;
    match_most_sqsb(mf_sb==mf_sq)=1;
    mean(mean(match_most_sqsb))

    match_most_sbci=mf_sq*0;
    match_most_sbci(mf_sb==mf_ci)=1;
    mean(mean(match_most_sbci))

    match_most_sqci=mf_sq*0;
    match_most_sqci(mf_sq==mf_ci)=1;
    mean(mean(match_most_sqci))

    % the modal town matches across all three counterfactuals...
    match_most_all=match_most_sqsb+match_most_sqci+match_most_sbci;
    bop=tabulate(match_most_all);
    shop=size(bop);
    match_mode_storage(param_i)=bop(shop(1),shop(2))
    
    
end;

%% display results

display("percent with same location, base parameters, full sample")

match_mode_storage

display("actual total exemptions, full sample")

total_subsidy

display("status quo simulation total exemptions, full sample")

sq_total_subsidy

display("subsidy ban simulation total exemptions, full sample")

sb_total_subsidy

display("county ida simulation total exemptions, full sample")

ci_total_subsidy
